@@ -216,7 +216,7 @@ Parser::~Parser()
     delete d;
 }
 
-Parser::Parser(const Parser &other) : AbstractParser(other), d(0) {}
+Parser::Parser(const Parser &other) : AbstractParser(other), d(nullptr) {}
 Parser &Parser::operator=(const Parser & /*other*/)
 {
     return *this;
